from status_ok.status_codex import status_codes

def getStatusMsg(status_code):
    if status_code not in status_codes:
        return "Unknown status code"

    return status_codes[status_code]


def getAllStatusCode():
    return status_codes


def setStatusCode(status_code , msg):
    try:
        status_codes[status_code] = msg
        return True
    except Exception as e:
        print(e)
        return False




from status_ok.status_codex import status_codes

class HttpStatusError(Exception):
    def __init__(self, expected, actual):
        self.expected = expected
        self.actual = actual
        super().__init__(f"Response mismatch. Expected: {expected} {status_codes[expected]}, "
                         f"Actual: {actual} {status_codes[actual]}")


def check_status_code(response , expected_status , expected_content = None):

    if expected_content is not None:
        if response.content != expected_content:
            raise HttpStatusError( expected_content , response.content)

    if response.status_code not in status_codes:
            raise HttpStatusError(expected_status , response.status_code)

    if expected_status != response.status_code:
        raise HttpStatusError( expected_status , response.status_code)







from setuptools import setup, find_packages

LICENSE = 'MIT'
REQUIRES = [
    'requests',
]

setup(
    name="status_ok",
    version="0.0.3",
    description="This library is used to handle http responses.",
    long_description="This library is used to handle http responses in python.",
    long_description_content_type='text/markdown',
    author="yuvraj jaiswal",
    author_email="y.jaiswal@thesynapses.com",
    url="https://github.com/iLS-yuvrajj/statusOk/tree/main",
    license=LICENSE,
    packages=find_packages(),
    install_requires=REQUIRES,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)